Documentation
¶
Overview ¶
Package encoding provides encoding and decoding capabilities for different encodings.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Encoding ¶
type Encoding byte
Encoding identifies referenced encoding formats.
func (Encoding) Available ¶
Available returns nil if the encoding is available, and an error if not.
func (Encoding) Decode ¶
Decode returns the receiver struct filled with the decoding of the encoded input. Returns an error if it fails.
Click to show internal directories.
Click to hide internal directories.